Currency enum
Currency enum provide all the currencies AllCurrency class provide all the currencies AllCurrency.allCurrencyWithCountries is the static array for the information about country and its currency name
Values
- inchNetwork → const Currency
- aave → const Currency
- ada → const Currency
- aed → const Currency
- afn → const Currency
- agix → const Currency
- akt → const Currency
- algo → const Currency
- all → const Currency
- amd → const Currency
- amp → const Currency
- ang → const Currency
- aoa → const Currency
- ape → const Currency
- apt → const Currency
- ar → const Currency
- arb → const Currency
- ars → const Currency
- atom → const Currency
- ats → const Currency
- aud → const Currency
- avax → const Currency
- awg → const Currency
- axs → const Currency
- azm → const Currency
- azn → const Currency
- bake → const Currency
- bam → const Currency
- bat → const Currency
- bbd → const Currency
- bch → const Currency
- bdt → const Currency
- bef → const Currency
- bgn → const Currency
- bhd → const Currency
- bif → const Currency
- bmd → const Currency
- bnb → const Currency
- bnd → const Currency
- bob → const Currency
- brl → const Currency
- bsd → const Currency
- bsv → const Currency
- bsw → const Currency
- btc → const Currency
- btcb → const Currency
- btg → const Currency
- btn → const Currency
- btt → const Currency
- busd → const Currency
- bwp → const Currency
- byn → const Currency
- byr → const Currency
- bzd → const Currency
- cad → const Currency
- cake → const Currency
- cdf → const Currency
- celo → const Currency
- cfx → const Currency
- chf → const Currency
- chz → const Currency
- clp → const Currency
- cnh → const Currency
- cny → const Currency
- comp → const Currency
- cop → const Currency
- crc → const Currency
- cro → const Currency
- crv → const Currency
- cspr → const Currency
- cuc → const Currency
- cup → const Currency
- cve → const Currency
- cvx → const Currency
- cyp → const Currency
- czk → const Currency
- dai → const Currency
- dash → const Currency
- dcr → const Currency
- dem → const Currency
- dfi → const Currency
- djf → const Currency
- dkk → const Currency
- doge → const Currency
- dop → const Currency
- dot → const Currency
- dydx → const Currency
- dzd → const Currency
- eek → const Currency
- egld → const Currency
- egp → const Currency
- enj → const Currency
- eos → const Currency
- ern → const Currency
- esp → const Currency
- etb → const Currency
- etc → const Currency
- eth → const Currency
- eur → const Currency
- eurc → const Currency
- fei → const Currency
- fil → const Currency
- fim → const Currency
- fjd → const Currency
- fkp → const Currency
- flow → const Currency
- flr → const Currency
- frax → const Currency
- frf → const Currency
- ftt → const Currency
- gala → const Currency
- gbp → const Currency
- gel → const Currency
- ggp → const Currency
- ghc → const Currency
- ghs → const Currency
- gip → const Currency
- gmd → const Currency
- gmx → const Currency
- gnf → const Currency
- gno → const Currency
- grd → const Currency
- grt → const Currency
- gt → const Currency
- gtq → const Currency
- gusd → const Currency
- gyd → const Currency
- hbar → const Currency
- hkd → const Currency
- hnl → const Currency
- hnt → const Currency
- hot → const Currency
- hrk → const Currency
- ht → const Currency
- htg → const Currency
- huf → const Currency
- icp → const Currency
- idr → const Currency
- iep → const Currency
- ils → const Currency
- imp → const Currency
- imx → const Currency
- inj → const Currency
- inr → const Currency
- iqd → const Currency
- irr → const Currency
- isk → const Currency
- itl → const Currency
- jep → const Currency
- jmd → const Currency
- jod → const Currency
- jpy → const Currency
- kas → const Currency
- kava → const Currency
- kcs → const Currency
- kda → const Currency
- kes → const Currency
- kgs → const Currency
- khr → const Currency
- kmf → const Currency
- knc → const Currency
- kpw → const Currency
- krw → const Currency
- ksm → const Currency
- kwd → const Currency
- kyd → const Currency
- kzt → const Currency
- lak → const Currency
- lbp → const Currency
- ldo → const Currency
- leo → const Currency
- link → const Currency
- lkr → const Currency
- lrc → const Currency
- lrd → const Currency
- lsl → const Currency
- ltc → const Currency
- ltl → const Currency
- luf → const Currency
- luna → const Currency
- lunc → const Currency
- lvl → const Currency
- lyd → const Currency
- mad → const Currency
- mana → const Currency
- mbx → const Currency
- mdl → const Currency
- mga → const Currency
- mgf → const Currency
- mina → const Currency
- mkd → const Currency
- mkr → const Currency
- mmk → const Currency
- mnt → const Currency
- mop → const Currency
- mro → const Currency
- mru → const Currency
- mtl → const Currency
- mur → const Currency
- mvr → const Currency
- mwk → const Currency
- mxn → const Currency
- mxv → const Currency
- myr → const Currency
- mzm → const Currency
- mzn → const Currency
- nad → const Currency
- near → const Currency
- neo → const Currency
- nexo → const Currency
- nft → const Currency
- ngn → const Currency
- nio → const Currency
- nlg → const Currency
- nok → const Currency
- npr → const Currency
- nzd → const Currency
- okb → const Currency
- omr → const Currency
- one → const Currency
- op → const Currency
- ordi → const Currency
- pab → const Currency
- paxg → const Currency
- pen → const Currency
- pepe → const Currency
- pgk → const Currency
- php → const Currency
- pi → const Currency
- pkr → const Currency
- pln → const Currency
- pol → const Currency
- pte → const Currency
- pyg → const Currency
- qar → const Currency
- qnt → const Currency
- qtum → const Currency
- rol → const Currency
- ron → const Currency
- rpl → const Currency
- rsd → const Currency
- rub → const Currency
- rune → const Currency
- rvn → const Currency
- rwf → const Currency
- sand → const Currency
- sar → const Currency
- sbd → const Currency
- scr → const Currency
- sdd → const Currency
- sdg → const Currency
- sek → const Currency
- sgd → const Currency
- shib → const Currency
- shp → const Currency
- sit → const Currency
- skk → const Currency
- sle → const Currency
- sll → const Currency
- snx → const Currency
- sol → const Currency
- sos → const Currency
- spl → const Currency
- srd → const Currency
- srg → const Currency
- ssp → const Currency
- std → const Currency
- stn → const Currency
- stx → const Currency
- sui → const Currency
- svc → const Currency
- syp → const Currency
- szl → const Currency
- thb → const Currency
- theta → const Currency
- tjs → const Currency
- tmm → const Currency
- tmt → const Currency
- tnd → const Currency
- ton → const Currency
- top → const Currency
- trl → const Currency
- trx → const Currency
- turkisL → const Currency
- ttd → const Currency
- tusd → const Currency
- tvd → const Currency
- twd → const Currency
- twt → const Currency
- tzs → const Currency
- uah → const Currency
- ugx → const Currency
- uni → const Currency
- usd → const Currency
- usdc → const Currency
- usdd → const Currency
- usdp → const Currency
- usdt → const Currency
- uyu → const Currency
- uzs → const Currency
- val → const Currency
- veb → const Currency
- ved → const Currency
- vef → const Currency
- ves → const Currency
- vet → const Currency
- vnd → const Currency
- vuv → const Currency
- waves → const Currency
- wemix → const Currency
- woo → const Currency
- wst → const Currency
- xaf → const Currency
- xag → const Currency
- xau → const Currency
- xaut → const Currency
- xbt → const Currency
- xcd → const Currency
- xcg → const Currency
- xch → const Currency
- xdc → const Currency
- xdr → const Currency
- xec → const Currency
- xem → const Currency
- xlm → const Currency
- xmr → const Currency
- xof → const Currency
- xpd → const Currency
- xpf → const Currency
- xpt → const Currency
- xrp → const Currency
- xtz → const Currency
- yer → const Currency
- zar → const Currency
- zec → const Currency
- zil → const Currency
- zmk → const Currency
- zmw → const Currency
- zwd → const Currency
- zwg → const Currency
- zwl → const Currency
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited